# DPFP-pytorch

Implementation of [DPFP](https://arxiv.org/pdf/2102.11174v2.pdf) in pytorch as provided in the paper.

## Install

```
$ pip install dpfp-pytorch
```

# Usage
```py3
from dpfp_pytorch import dpfp

```
